@@ -1,7 +1,7 @@
 package Mail::DKIM::ARC::Verifier;
 use strict;
 use warnings;
-our $VERSION = '1.20230911'; # VERSION
+our $VERSION = '1.20240124'; # VERSION
 # ABSTRACT: verifies an ARC-Sealed message
 
 # Copyright 2017 FastMail Pty Ltd.  All Rights Reserved.
@@ -158,7 +158,7 @@ sub add_signature {
         my ($instance);
         $instance = $signature->instance() || '';
 
-        if ( $instance !~ m{^\d+$} or $instance < 1 or $instance > 1024 ) {
+        if ( $instance !~ m{^\d+$} or $instance < 1 or $instance > $MAX_SIGNATURES_TO_PROCESS ) {
             $self->{result}  = 'fail';                                   # bogus
             $self->{details} = sprintf "Invalid ARC-Seal instance '%s'",
               $instance;
@@ -181,7 +181,7 @@ sub add_signature {
     elsif ( $signature->isa('Mail::DKIM::ARC::MessageSignature') ) {
         my $instance = $signature->instance() || '';
 
-        if ( $instance !~ m{^\d+$} or $instance < 1 or $instance > 1024 ) {
+        if ( $instance !~ m{^\d+$} or $instance < 1 or $instance > $MAX_SIGNATURES_TO_PROCESS ) {
             $self->{result} = 'fail';    # bogus
             $self->{details} =
               sprintf "Invalid ARC-Message-Signature instance '%s'", $instance;
@@ -621,7 +621,7 @@ Mail::DKIM::ARC::Verifier - verifies an ARC-Sealed message
 
 =head1 VERSION
 
-version 1.20230911
+version 1.20240124
 
 =head1 SYNOPSIS
 
